@@ -7,6 +7,7 @@ __all__ = [
     'apple_pay_api',
     'bank_accounts_api',
     'bookings_api',
+    'cards_api',
     'cash_drawers_api',
     'catalog_api',
     'customers_api',
@@ -15,6 +16,8 @@ __all__ = [
     'devices_api',
     'disputes_api',
     'employees_api',
+    'gift_cards_api',
+    'gift_card_activities_api',
     'inventory_api',
     'invoices_api',
     'labor_api',
