@@ -18,8 +18,8 @@ class CheckoutApi(BaseApi):
                         body):
         """Does a POST request to /v2/locations/{location_id}/checkouts.
 
-        Links a `checkoutId` to a `checkout_page_url` that customers will
-        be directed to in order to provide their payment information using a
+        Links a `checkoutId` to a `checkout_page_url` that customers are
+        directed to in order to provide their payment information using a
         payment processing workflow hosted on connect.squareup.com.
 
         Args:
