@@ -21,7 +21,7 @@ class InvoicesApi(BaseApi):
 
         Returns a list of invoices for a given location. The response 
         is paginated. If truncated, the response includes a `cursor` that you 
-                use in a subsequent request to fetch the next set of invoices.
+                use in a subsequent request to retrieve the next set of invoices.
 
         Args:
             location_id (string): The ID of the location for which to list
@@ -33,7 +33,7 @@ class InvoicesApi(BaseApi):
                 [Pagination](https://developer.squareup.com/docs/working-with-a
                 pis/pagination).
             limit (int, optional): The maximum number of invoices to return
-                (200 is the maximum `limit`).  If not provided, the server 
+                (200 is the maximum `limit`).  If not provided, the server
                 uses a default limit of 100 invoices.
 
         Returns:
@@ -85,7 +85,7 @@ class InvoicesApi(BaseApi):
                        body):
         """Does a POST request to /v2/invoices.
 
-        Creates a draft [invoice](#type-invoice) 
+        Creates a draft [invoice]($m/Invoice) 
         for an order created using the Orders API.
         A draft invoice remains in your account and no action is taken. 
         You must publish the invoice before Square can process it (send it to
@@ -145,7 +145,7 @@ class InvoicesApi(BaseApi):
         optionally one customer.
         The response is paginated. If truncated, the response includes a
         `cursor` 
-        that you use in a subsequent request to fetch the next set of
+        that you use in a subsequent request to retrieve the next set of
         invoices.
 
         Args:
@@ -196,18 +196,17 @@ class InvoicesApi(BaseApi):
         """Does a DELETE request to /v2/invoices/{invoice_id}.
 
         Deletes the specified invoice. When an invoice is deleted, the 
-        associated Order status changes to CANCELED. You can only delete a
+        associated order status changes to CANCELED. You can only delete a
         draft 
         invoice (you cannot delete a published invoice, including one that is
         scheduled for processing).
 
         Args:
             invoice_id (string): The ID of the invoice to delete.
-            version (int, optional): The version of the
-                [invoice](#type-invoice) to delete. If you do not know the
-                version, you can call
-                [GetInvoice](#endpoint-Invoices-GetInvoice) or 
-                [ListInvoices](#endpoint-Invoices-ListInvoices).
+            version (int, optional): The version of the [invoice]($m/Invoice)
+                to delete. If you do not know the version, you can call
+                [GetInvoice]($e/Invoices/GetInvoice) or 
+                [ListInvoices]($e/Invoices/ListInvoices).
 
         Returns:
             ApiResponse: An object with the response value as well as other
@@ -262,7 +261,7 @@ class InvoicesApi(BaseApi):
         Retrieves an invoice by invoice ID.
 
         Args:
-            invoice_id (string): The id of the invoice to retrieve.
+            invoice_id (string): The ID of the invoice to retrieve.
 
         Returns:
             ApiResponse: An object with the response value as well as other
@@ -310,10 +309,10 @@ class InvoicesApi(BaseApi):
 
         Updates an invoice by modifying fields, clearing fields, or both. For
         most updates, you can use a sparse 
-        `Invoice` object to add fields or change values, and use the
+        `Invoice` object to add fields or change values and use the
         `fields_to_clear` field to specify fields to clear. 
         However, some restrictions apply. For example, you cannot change the
-        `order_id` or `location_id` field, and you 
+        `order_id` or `location_id` field and you 
         must provide the complete `custom_fields` list to update a custom
         field. Published invoices have additional restrictions.
 
@@ -374,7 +373,7 @@ class InvoicesApi(BaseApi):
         state: `PAID`, `REFUNDED`, `CANCELED`, or `FAILED`.
 
         Args:
-            invoice_id (string): The ID of the [invoice](#type-invoice) to
+            invoice_id (string): The ID of the [invoice]($m/Invoice) to
                 cancel.
             body (CancelInvoiceRequest): An object containing the fields to
                 POST for the request.  See the corresponding object definition
@@ -437,10 +436,10 @@ class InvoicesApi(BaseApi):
         `UNPAID` if 
         Square emails the invoice or `PARTIALLY_PAID` if Square charge a card
         on file for a portion of the 
-        invoice amount).
+        invoice amount.
 
         Args:
-            invoice_id (string): The id of the invoice to publish.
+            invoice_id (string): The ID of the invoice to publish.
             body (PublishInvoiceRequest): An object containing the fields to
                 POST for the request.  See the corresponding object definition
                 for field details.
