@@ -18,7 +18,7 @@ class LocationsApi(BaseApi):
 
         Provides information of all locations of a business.
         Many Square API endpoints require a `location_id` parameter.
-        The `id` field of the [`Location`](#type-location) objects returned by
+        The `id` field of the [`Location`]($m/Location) objects returned by
         this
         endpoint correspond to that `location_id` parameter.
 
