@@ -203,9 +203,9 @@ class TransactionsApi(BaseApi):
         Charges a card represented by a card nonce or a customer's card on
         file.
         Your request to this endpoint must include _either_:
-        - A value for the `card_nonce` parameter (to charge a card nonce
-        generated
-        with the `SqPaymentForm`)
+        - A value for the `card_nonce` parameter (to charge a card payment
+        token generated
+        with the Web Payments SDK)
         - Values for the `customer_card_id` and `customer_id` parameters (to
         charge
         a customer's card on file)
